create_image_from_data

Function create_image_from_data 

pub fn create_image_from_data(
    data: Vec<u8>,
    sheet_config: &SpriteSheetConfig,
    sheet_size: &UVec2,
) -> Result<RgbaImage>
Creates a sprite sheet image from a given CIP decompressed bmp and saves it to the given output path. The sprite sheet is expected to have 384x384 pixels and 4 channels (RGBA). The data is expected to be in the BGRA format. The data is expected to be flipped vertically. The data is expected to have a 122 byte header that we need to skip