pub struct EventSender<T>(pub Sender<T>);Expand description
A resource that emits asynchronous events of a given type.
It’s a bevy friendly wrapper around a std::sync::mpsc::Sender.
Tuple Fields
0: Sender<T>Methods from Deref<Target = Sender<T>>
1.0.0 · Sourcepub fn send(&self, t: T) -> Result<(), SendError<T>>
pub fn send(&self, t: T) -> Result<(), SendError<T>>
Attempts to send a value on this channel, returning it back if it could not be sent.
A successful send occurs when it is determined that the other end of
the channel has not hung up already. An unsuccessful send would be one
where the corresponding receiver has already been deallocated. Note
that a return value of Err means that the data will never be
received, but a return value of Ok does not mean that the data
will be received. It is possible for the corresponding receiver to
hang up immediately after this function returns Ok.
This method will never block the current thread.
Examples
use std::sync::mpsc::channel;
let (tx, rx) = channel();
// This send is always successful
tx.send(1).unwrap();
// This send will fail because the receiver is gone
drop(rx);
assert_eq!(tx.send(1).unwrap_err().0, 1);Trait Implementations
Sourceimpl<T> Deref for EventSender<T>
impl<T> Deref for EventSender<T>
Sourceimpl<T> DerefMut for EventSender<T>
impl<T> DerefMut for EventSender<T>
impl<T> Resource for EventSender<T>